#
# spec file for package winff
#
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/

Name:           winff
Version:        1.5.5
Release:        1.9
License:        GPL-3.0+
Summary:        Multimedia File Converter
Url:            http://winff.org
Group:          Productivity/Multimedia/Video/Editors and Convertors
Source0:        http://winff.org/docs/source/winff-%{version}-source.tar.gz
Source1:        winff.desktop
Patch0:         winff-64bit_build.patch
BuildRequires:  atk-devel
BuildRequires:  lazarus
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(pango)
Requires:       ffmpeg
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
WinFF is a GUI for the command line video converter, FFMPEG. It will convert
any video file that FFmpeg will convert. WinFF does multiple files in multiple
formats at one time. You can for example convert mpeg's, flv's, and mov's, all
into avi's all at once.

%lang_package

%prep
%setup -q -n %{name}
%patch0 -p1
# rmove exec bits
chmod a-x {README.txt,changelog.txt,AUTHORS,README-Presets.txt}

%build
lazbuild \
%ifarch x86_64
  --cpu=x86_64 \
%endif
  --widgetset=gtk2 \
  -B winff.lpr

%install
install -D -m 0755 winff "%{buildroot}%{_bindir}/winff"
install -d -m 0755 "%{buildroot}%{_datadir}/winff"
find . -name '*.xml' \
    -exec install -D -m0644 {} "%{buildroot}%{_datadir}/winff/" \;
install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
for s in 16 24 32 48; do
    install -D -m0644 "winff-icons/${s}x${s}/winff.png" \
        "%{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/winff.png"
done

install -d -m0755 "%{buildroot}%{_datadir}/winff/languages"
find . -name '*.po' -exec install -D -m0644 {} "%{buildroot}%{_datadir}/winff/languages/" \;

%suse_update_desktop_file -r "%{name}" AudioVideo AudioVideoEditing

L="$PWD/%{name}.lang"; echo -n >"$L"
B="%{_datadir}/winff/languages"
pushd "%{buildroot}$B"
/bin/ls -1 winff.*.po | while read po; do
    l="${po%.po}"
    l="${l#winff.}"
    echo "%lang($l) $B/$po" >>"$L"
done
popd

%files
%defattr(-,root,root)
%doc AUTHORS *.txt
%{_bindir}/winff
%dir %{_datadir}/winff
%dir %{_datadir}/winff/languages
%lang(en) %{_datadir}/winff/languages/winff.po
%config %{_datadir}/winff/presets.xml
%{_datadir}/icons/*/*/apps/winff.*
%{_datadir}/applications/%{name}.desktop

%files lang -f "%{name}.lang"
%defattr(-,root,root)

%changelog
* Fri Nov 18 2016 aloisio@gmx.com
- Update to version 1.5.5
  * Update translations with status from Launchpad and
    Debian (nl)
  * Import preset's menu open the dialog to the extras path
    (/usr/share/winff)
  * Set default preset to mpeg4 720p
  * Cleaned up presets.xml
  * Added Sinhala translation
  1.5.4
  * Fixed drag drop bug: numfiles was not initialised.
    Could countain random number, not actual files dragged and
    dropped. Max number of jobs was not being incremented on
    dragdrop.
    Now, if you dragdrop and the file list goes > max number
    of jobs, we add 50 more rows to filelist.
    note: file list is initially limited to 100 jobs because
    of the memory overhead of maintaining arrays of the
    filenames, command lines, options settings, etc.
  * Enhancement: added hint for file list showing number of
    files in queue when cursor not over a filename.
  - Refreshed winff-64bit_build.patch
* Thu May 22 2014 fisiu@opensuse.org
- Update to 1.5.3.
* Tue Nov 19 2013 joerg.lorenzen@ki.tng.de
- added patch to build on x86_64
* Wed Sep 18 2013 fisiu@opensuse.org
- Update to 1.5.2.
* Sun Apr 29 2012 pascal.bleser@opensuse.org
- initial version (1.4.2)
